@@ -25,20 +25,8 @@ class addTrafficMonitorResponse (baseResponse):
         self.ipaddress = None
         """the number of times to retry requests to the external firewall"""
         self.numretries = None
-        """the private interface of the external firewall"""
-        self.privateinterface = None
-        """the private security zone of the external firewall"""
-        self.privatezone = None
-        """the public interface of the external firewall"""
-        self.publicinterface = None
-        """the public security zone of the external firewall"""
-        self.publiczone = None
         """the timeout (in seconds) for requests to the external firewall"""
         self.timeout = None
-        """the usage interface of the external firewall"""
-        self.usageinterface = None
-        """the username that's used to log in to the external firewall"""
-        self.username = None
         """the zone ID of the external firewall"""
         self.zoneid = None
 
