@@ -15,14 +15,8 @@ class addVpnUserCmd (baseCmd):
         self.account = None
         """an optional domainId for the vpn user. If the account parameter is used, domainId must also be used."""
         self.domainid = None
-        """"""
-        self.id = None
-        """"""
-        self.id = None
         """add vpn user to the specific project"""
         self.projectid = None
-        """"""
-        self.starteventid = None
         self.required = ["password","username",]
 
 class addVpnUserResponse (baseResponse):
