@@ -177,6 +177,7 @@ from deleteVolume import deleteVolumeResponse
 from listVolumes import listVolumesResponse
 from extractVolume import extractVolumeResponse
 from migrateVolume import migrateVolumeResponse
+from resizeVolume import resizeVolumeResponse
 from registerUserKeys import registerUserKeysResponse
 from queryAsyncJobResult import queryAsyncJobResultResponse
 from listAsyncJobs import listAsyncJobsResponse
@@ -295,10 +296,50 @@ from listUsageTypes import listUsageTypesResponse
 from addTrafficMonitor import addTrafficMonitorResponse
 from deleteTrafficMonitor import deleteTrafficMonitorResponse
 from listTrafficMonitors import listTrafficMonitorsResponse
+from deleteCiscoNexusVSM import deleteCiscoNexusVSMResponse
+from enableCiscoNexusVSM import enableCiscoNexusVSMResponse
+from disableCiscoNexusVSM import disableCiscoNexusVSMResponse
+from listCiscoNexusVSMs import listCiscoNexusVSMsResponse
+from addExternalLoadBalancer import addExternalLoadBalancerResponse
+from deleteExternalLoadBalancer import deleteExternalLoadBalancerResponse
+from listExternalLoadBalancers import listExternalLoadBalancersResponse
+from addF5LoadBalancer import addF5LoadBalancerResponse
+from configureF5LoadBalancer import configureF5LoadBalancerResponse
+from deleteF5LoadBalancer import deleteF5LoadBalancerResponse
+from listF5LoadBalancers import listF5LoadBalancersResponse
+from listF5LoadBalancerNetworks import listF5LoadBalancerNetworksResponse
+from addExternalFirewall import addExternalFirewallResponse
+from deleteExternalFirewall import deleteExternalFirewallResponse
+from listExternalFirewalls import listExternalFirewallsResponse
+from addSrxFirewall import addSrxFirewallResponse
+from deleteSrxFirewall import deleteSrxFirewallResponse
+from configureSrxFirewall import configureSrxFirewallResponse
+from listSrxFirewalls import listSrxFirewallsResponse
+from listSrxFirewallNetworks import listSrxFirewallNetworksResponse
+from createVolumeOnFiler import createVolumeOnFilerResponse
+from destroyVolumeOnFiler import destroyVolumeOnFilerResponse
+from listVolumesOnFiler import listVolumesOnFilerResponse
+from createLunOnFiler import createLunOnFilerResponse
+from destroyLunOnFiler import destroyLunOnFilerResponse
+from listLunsOnFiler import listLunsOnFilerResponse
+from associateLun import associateLunResponse
+from dissociateLun import dissociateLunResponse
+from createPool import createPoolResponse
+from deletePool import deletePoolResponse
+from modifyPool import modifyPoolResponse
+from listPools import listPoolsResponse
+from addNetscalerLoadBalancer import addNetscalerLoadBalancerResponse
+from deleteNetscalerLoadBalancer import deleteNetscalerLoadBalancerResponse
+from configureNetscalerLoadBalancer import configureNetscalerLoadBalancerResponse
+from listNetscalerLoadBalancers import listNetscalerLoadBalancersResponse
+from listNetscalerLoadBalancerNetworks import listNetscalerLoadBalancerNetworksResponse
 from addNiciraNvpDevice import addNiciraNvpDeviceResponse
 from deleteNiciraNvpDevice import deleteNiciraNvpDeviceResponse
 from listNiciraNvpDevices import listNiciraNvpDevicesResponse
 from listNiciraNvpDeviceNetworks import listNiciraNvpDeviceNetworksResponse
+from listApis import listApisResponse
+from getApiLimit import getApiLimitResponse
+from resetApiLimit import resetApiLimitResponse
 from login import loginResponse
 from logout import logoutResponse
 class CloudStackAPIClient:
@@ -1193,6 +1234,11 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
+    def resizeVolume(self,command):
+        response = resizeVolumeResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
     def registerUserKeys(self,command):
         response = registerUserKeysResponse()
         response = self.connection.make_request(command, response)
@@ -1783,6 +1829,191 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
+    def deleteCiscoNexusVSM(self,command):
+        response = deleteCiscoNexusVSMResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def enableCiscoNexusVSM(self,command):
+        response = enableCiscoNexusVSMResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def disableCiscoNexusVSM(self,command):
+        response = disableCiscoNexusVSMResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listCiscoNexusVSMs(self,command):
+        response = listCiscoNexusVSMsResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def addExternalLoadBalancer(self,command):
+        response = addExternalLoadBalancerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def deleteExternalLoadBalancer(self,command):
+        response = deleteExternalLoadBalancerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listExternalLoadBalancers(self,command):
+        response = listExternalLoadBalancersResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def addF5LoadBalancer(self,command):
+        response = addF5LoadBalancerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def configureF5LoadBalancer(self,command):
+        response = configureF5LoadBalancerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def deleteF5LoadBalancer(self,command):
+        response = deleteF5LoadBalancerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listF5LoadBalancers(self,command):
+        response = listF5LoadBalancersResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listF5LoadBalancerNetworks(self,command):
+        response = listF5LoadBalancerNetworksResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def addExternalFirewall(self,command):
+        response = addExternalFirewallResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def deleteExternalFirewall(self,command):
+        response = deleteExternalFirewallResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listExternalFirewalls(self,command):
+        response = listExternalFirewallsResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def addSrxFirewall(self,command):
+        response = addSrxFirewallResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def deleteSrxFirewall(self,command):
+        response = deleteSrxFirewallResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def configureSrxFirewall(self,command):
+        response = configureSrxFirewallResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listSrxFirewalls(self,command):
+        response = listSrxFirewallsResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listSrxFirewallNetworks(self,command):
+        response = listSrxFirewallNetworksResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def createVolumeOnFiler(self,command):
+        response = createVolumeOnFilerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def destroyVolumeOnFiler(self,command):
+        response = destroyVolumeOnFilerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listVolumesOnFiler(self,command):
+        response = listVolumesOnFilerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def createLunOnFiler(self,command):
+        response = createLunOnFilerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def destroyLunOnFiler(self,command):
+        response = destroyLunOnFilerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listLunsOnFiler(self,command):
+        response = listLunsOnFilerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def associateLun(self,command):
+        response = associateLunResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def dissociateLun(self,command):
+        response = dissociateLunResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def createPool(self,command):
+        response = createPoolResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def deletePool(self,command):
+        response = deletePoolResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def modifyPool(self,command):
+        response = modifyPoolResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listPools(self,command):
+        response = listPoolsResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def addNetscalerLoadBalancer(self,command):
+        response = addNetscalerLoadBalancerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def deleteNetscalerLoadBalancer(self,command):
+        response = deleteNetscalerLoadBalancerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def configureNetscalerLoadBalancer(self,command):
+        response = configureNetscalerLoadBalancerResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listNetscalerLoadBalancers(self,command):
+        response = listNetscalerLoadBalancersResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def listNetscalerLoadBalancerNetworks(self,command):
+        response = listNetscalerLoadBalancerNetworksResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
     def addNiciraNvpDevice(self,command):
         response = addNiciraNvpDeviceResponse()
         response = self.connection.make_request(command, response)
@@ -1803,6 +2034,21 @@ class CloudStackAPIClient:
         response = self.connection.make_request(command, response)
         return response
 
+    def listApis(self,command):
+        response = listApisResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def getApiLimit(self,command):
+        response = getApiLimitResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
+    def resetApiLimit(self,command):
+        response = resetApiLimitResponse()
+        response = self.connection.make_request(command, response)
+        return response
+
     def login(self,command):
         response = loginResponse()
         response = self.connection.make_request(command, response)
