@@ -14,12 +14,6 @@ class createCounterCmd (baseCmd):
         """Value of the counter e.g. oid in case of snmp."""
         """Required"""
         self.value = None
-        """"""
-        self.id = None
-        """"""
-        self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["name","source","value",]
 
 class createCounterResponse (baseResponse):
