@@ -8,8 +8,6 @@ class deleteFirewallRuleCmd (baseCmd):
         """the ID of the firewall rule"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deleteFirewallRuleResponse (baseResponse):
