@@ -8,8 +8,6 @@ class deleteNetworkCmd (baseCmd):
         """the ID of the network"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deleteNetworkResponse (baseResponse):
