@@ -8,8 +8,6 @@ class deleteVpnConnectionCmd (baseCmd):
         """id of vpn connection"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deleteVpnConnectionResponse (baseResponse):
