@@ -8,8 +8,6 @@ class deleteVpnGatewayCmd (baseCmd):
         """id of customer gateway"""
         """Required"""
         self.id = None
-        """"""
-        self.starteventid = None
         self.required = ["id",]
 
 class deleteVpnGatewayResponse (baseResponse):
