@@ -28,10 +28,6 @@ class deployVirtualMachineCmd (baseCmd):
         self.hostid = None
         """the hypervisor on which to deploy the virtual machine"""
         self.hypervisor = None
-        """"""
-        self.id = None
-        """"""
-        self.id = None
         """the ip address for default vm's network"""
         self.ipaddress = None
         """ip to network mapping. Can't be specified with networkIds parameter. Example: iptonetworklist[0].ip=10.10.10.11&iptonetworklist[0].networkid=uuid - requests to use ip 10.10.10.11 in network id=uuid"""
@@ -52,8 +48,6 @@ class deployVirtualMachineCmd (baseCmd):
         self.securitygroupnames = []
         """the arbitrary size for the DATADISK volume. Mutually exclusive with diskOfferingId"""
         self.size = None
-        """"""
-        self.starteventid = None
         """true if network offering supports specifying ip ranges; defaulted to true if not specified"""
         self.startvm = None
         """an optional binary data that can be sent to the virtual machine upon a successful deployment. This binary data must be base64 encoded before adding it to the request. Currently only HTTP GET is supported. Using HTTP GET (via querystring), you can send up to 2KB of data after base64 encoding."""
