@@ -5,7 +5,7 @@ from baseResponse import *
 class listIsosCmd (baseCmd):
     def __init__(self):
         self.isAsync = "false"
-        """List resources by account. Must be used with the domainId parameter."""
+        """list resources by account. Must be used with the domainId parameter."""
         self.account = None
         """true if the ISO is bootable, false otherwise"""
         self.bootable = None
