@@ -8,7 +8,7 @@ class listTemplatesCmd (baseCmd):
         """possible values are "featured", "self", "self-executable", "executable", and "community".* featured-templates that are featured and are public* self-templates that have been registered/created by the owner* selfexecutable-templates that have been registered/created by the owner that can be used to deploy a new VM* executable-all templates that can be used to deploy a new VM* community-templates that are public."""
         """Required"""
         self.templatefilter = None
-        """List resources by account. Must be used with the domainId parameter."""
+        """list resources by account. Must be used with the domainId parameter."""
         self.account = None
         """list only resources belonging to the domain specified"""
         self.domainid = None
