@@ -5,7 +5,7 @@ from baseResponse import *
 class listVpnUsersCmd (baseCmd):
     def __init__(self):
         self.isAsync = "false"
-        """List resources by account. Must be used with the domainId parameter."""
+        """list resources by account. Must be used with the domainId parameter."""
         self.account = None
         """list only resources belonging to the domain specified"""
         self.domainid = None
