@@ -10,8 +10,6 @@ class updateNetworkServiceProviderCmd (baseCmd):
         self.id = None
         """the list of services to be enabled for this physical network service provider"""
         self.servicelist = []
-        """"""
-        self.starteventid = None
         """Enabled/Disabled/Shutdown the physical network service provider"""
         self.state = None
         self.required = ["id",]
